@@ -368,24 +368,22 @@ gpdf_window_close (GPdfWindow *gpdf_window)
 {
 	g_return_if_fail (GPDF_IS_NON_NULL_WINDOW (gpdf_window));
 
-	bonobo_control_frame_set_autoactivate
-	  (bonobo_widget_get_control_frame (gpdf_window->priv->bonobo_widget),
-	   FALSE);
-	bonobo_control_frame_control_deactivate
-	  (bonobo_widget_get_control_frame (gpdf_window->priv->bonobo_widget));
+	if (gpdf_window_has_contents (gpdf_window)) {
+		bonobo_control_frame_set_autoactivate (
+			bonobo_widget_get_control_frame (
+				gpdf_window->priv->bonobo_widget),
+			FALSE);
+		bonobo_control_frame_control_deactivate (
+			bonobo_widget_get_control_frame (
+				gpdf_window->priv->bonobo_widget));
+	}
+
 	gtk_widget_destroy (GTK_WIDGET (gpdf_window));
 
 	if (window_list == NULL)
 		bonobo_main_quit ();
 }
 
-static void
-gw_close_all (void)
-{
-	while (window_list != NULL)
-		gpdf_window_close (GPDF_WINDOW (window_list->data));
-}
-
 static void
 gpdf_window_set_fullscreen (GPdfWindow *gpdf_window, gboolean fullscreen)
 {
@@ -602,6 +600,12 @@ gw_open_dialog (GPdfWindow *gpdf_window)
 	}
 }
 
+static void
+gw_open_file (GtkToolButton *toolbutton, gpointer data)
+{
+	gw_open_dialog (GPDF_WINDOW (data));
+}
+
 static gboolean
 gw_open_recent_file (EggRecentView *view, EggRecentItem *item, gpointer data)
 {
@@ -631,13 +635,6 @@ verb_FileClose_cb (BonoboUIComponent *uic, gpointer user_data,
 	gpdf_window_close (GPDF_WINDOW (user_data));
 }
 
-static void
-verb_FileExit_cb (BonoboUIComponent *uic, gpointer user_data,
-		  const char *cname)
-{
-	gw_close_all ();
-}
-
 static void
 listener_ViewFullScreen (BonoboUIComponent *uic, const char *path,
                          Bonobo_UIComponent_EventType type, const char *state,
@@ -654,16 +651,6 @@ listener_ViewFullScreen (BonoboUIComponent *uic, const char *path,
 	gpdf_window_set_fullscreen(GPDF_WINDOW (user_data), atoi (state));
 }
 
-
-/* Brings attention to a window by raising it and giving it focus */
-static void
-raise_and_focus (GtkWidget *widget)
-{
-	g_assert (GTK_WIDGET_REALIZED (widget));
-	gdk_window_show (widget->window);
-	gtk_widget_grab_focus (widget);
-}
-
 static void
 verb_HelpContents_cb (BonoboUIComponent *uic, gpointer user_data,
 		     const char *cname)
@@ -677,11 +664,9 @@ static void
 verb_HelpAbout_cb (BonoboUIComponent *uic, gpointer user_data,
 		   const char *cname)
 {
-	static GtkWidget *about;
+	char *tmp_str;
 
-	gchar *tmp_str;
-
-	static const gchar *authors[] = {
+	const char *authors[] = {
 		N_("Derek B. Noonburg, Xpdf author."),
 		N_("Martin Kretzschmar, GNOME port maintainer."),
 		N_("Michael Meeks, GNOME port creator."),
@@ -693,49 +678,43 @@ verb_HelpAbout_cb (BonoboUIComponent *uic, gpointer user_data,
 		NULL
 	};
 
-	static const gchar *documenters[] = {
+	const char *documenters[] = {
 		N_("Chee Bin HOH <cbhoh@mimos.my>"),
 		N_("Breda McColgan <BredaMcColgan@sun.com>"),
 		NULL
 	};
 
-	static const gchar *translators;
+	const char *translators;
 
-	if (!about) {
 #ifdef ENABLE_NLS
-		int i;
-		
-		for (i = 0; authors[i] != NULL; i++)
-			authors [i] = _(authors [i]);
+	const char **p;
+
+	for (p = authors; *p; ++p)
+		*p = _(*p);
+
+	for (p = documenters; *p; ++p)
+		*p = _(*p);
 #endif
 
-		translators = _("translator-credits");
+	translators = _("translator-credits");
 
-		tmp_str = g_strconcat ("Copyright \xc2\xa9 1996-2003 ",
-				     _("Glyph & Cog, LLC and authors"),
-				     NULL);
+	tmp_str = g_strconcat ("Copyright \xc2\xa9 1996-2004 ",
+			       _("Glyph & Cog, LLC and authors"),
+			       NULL);
 
-		about = gnome_about_new (
-			_("GNOME PDF Viewer"),
-			VERSION,
-			tmp_str,
-			_("A PDF viewer based on Xpdf"),
-			authors,
-			documenters,
-			(strcmp (translators,
-				 "translator-credits")
-			 ? translators : NULL),
-			NULL);
-	
-		g_signal_connect (about, "destroy",
-				  G_CALLBACK (gtk_widget_destroyed),
-				  &about);
+	gtk_show_about_dialog (
+		GTK_WINDOW (user_data),
+		"name", _("GNOME PDF Viewer"),
+		"version", VERSION,
+		"copyright", tmp_str,
+		"comments", _("A PDF viewer based on Xpdf"),
+		"icon-name", "gnome-pdf",
+		"authors", authors,
+		"documenters", documenters,
+		"translator-credits", _("translator-credits"),
+		NULL);
 
-		g_free (tmp_str);
-	}
-
-	gtk_widget_show_now (about);
-	raise_and_focus (about);
+	g_free (tmp_str);
 }
 
 
@@ -838,7 +817,6 @@ gw_setup_local_contents (GPdfWindow *gpdf_window)
 static BonoboUIVerb gw_verbs [] = {
 	BONOBO_UI_VERB ("FileOpen",  verb_FileOpen_cb),
 	BONOBO_UI_VERB ("FileClose", verb_FileClose_cb),
-	BONOBO_UI_VERB ("FileExit",  verb_FileExit_cb),
 
 	BONOBO_UI_VERB ("HelpContents", verb_HelpContents_cb),
 	BONOBO_UI_VERB ("HelpAbout", verb_HelpAbout_cb),
@@ -899,13 +877,17 @@ gw_setup_recent_toolitem (GPdfWindow *gpdf_window, GPdfRecentFacade *facade,
 	const EggRecentModel *model;
 
 	toolitem = GTK_WIDGET (g_object_new (GPDF_TYPE_RECENT_VIEW_TOOLITEM,
-					   NULL));
-	gtk_widget_show_all (GTK_WIDGET (toolitem));       
+					     "stock_id", GTK_STOCK_OPEN,
+					     NULL));
+	gtk_widget_show_all (GTK_WIDGET (toolitem));
 
 	model = gpdf_recent_facade_get_model (facade);
 
 	gpdf_recent_view_toolitem_set_model (
 		GPDF_RECENT_VIEW_TOOLITEM (toolitem), (EggRecentModel *)model);
+	g_signal_connect_object (G_OBJECT (toolitem), "clicked",
+				 G_CALLBACK (gw_open_file),
+				 gpdf_window, 0);
 	g_signal_connect_object (G_OBJECT (toolitem), "item_activate",
 				 G_CALLBACK (gw_open_recent_file),
 				 uri_in, 0);
