@@ -23,7 +23,6 @@
 #include "gpdf-bookmarks-view.h"
 #include "gpdf-thumbnails-view.h"
 #include "gpdf-annots-view.h"
-#include "gpdf-hig-dialog.h"
 #include "gpdf-util.h"
 #include "pdf-info-dict-util.h"
 #include "gpdf-g-switch.h"
@@ -446,19 +445,21 @@ gpdf_control_private_error_dialog (GPdfControl * control,
 				   gboolean modal,
 				   gboolean ref_parent)
 {
-	GtkWidget *dlg, *but;
+	GtkWidget *dlg;
 
 	g_return_if_fail (GPDF_IS_NON_NULL_CONTROL (control));
 	if (ref_parent)
 		bonobo_object_ref (BONOBO_OBJECT (control));
 
-	dlg = gpdf_hig_dialog_new (GTK_STOCK_DIALOG_ERROR,
-				   header_text,
-				   body_text,
-				   modal);
-	but = gtk_dialog_add_button (GTK_DIALOG (dlg),
-				     GTK_STOCK_OK,
-				     GTK_RESPONSE_OK);
+	dlg = gtk_message_dialog_new (NULL,
+				      (GtkDialogFlags)0,
+				      GTK_MESSAGE_ERROR,
+				      GTK_BUTTONS_OK,
+				      "%s", header_text);
+	gtk_message_dialog_format_secondary_text (
+		GTK_MESSAGE_DIALOG (dlg), "%s", body_text);
+	gtk_window_set_modal (GTK_WINDOW (dlg), modal);
+				      
 	bonobo_control_set_transient_for (BONOBO_CONTROL (control),
 					  GTK_WINDOW (dlg),
 					  NULL);
@@ -483,16 +484,19 @@ gpdf_control_private_warn_dialog (GPdfControl * control,
 				  const gchar *body_text,
 				  gboolean modal)
 {
-	GtkWidget *dlg, *but;
+	GtkWidget *dlg;
 
 	g_return_if_fail (GPDF_IS_NON_NULL_CONTROL (control));
-	dlg = gpdf_hig_dialog_new (GTK_STOCK_DIALOG_WARNING,
-				   header_text,
-				   body_text,
-				   modal);
-	but = gtk_dialog_add_button (GTK_DIALOG (dlg),
-				     GTK_STOCK_OK,
-				     GTK_RESPONSE_OK);
+
+	dlg = gtk_message_dialog_new (NULL,
+				      (GtkDialogFlags)0,
+				      GTK_MESSAGE_WARNING,
+				      GTK_BUTTONS_OK,
+				      "%s", header_text);
+	gtk_message_dialog_format_secondary_text (
+		GTK_MESSAGE_DIALOG (dlg), "%s", body_text);
+	gtk_window_set_modal (GTK_WINDOW (dlg), modal);
+
 	bonobo_control_set_transient_for (BONOBO_CONTROL (control),
 					  GTK_WINDOW (dlg),
 					  NULL);
@@ -513,16 +517,18 @@ gpdf_control_private_info_dialog (GPdfControl * control,
 				  const gchar *body_text,
 				  gboolean modal)
 {
-	GtkWidget *dlg, *but;
+	GtkWidget *dlg;
 
 	g_return_if_fail (GPDF_IS_NON_NULL_CONTROL (control));
-	dlg = gpdf_hig_dialog_new (GTK_STOCK_DIALOG_INFO,
-				   header_text,
-				   body_text,
-				   modal);
-	but = gtk_dialog_add_button (GTK_DIALOG (dlg),
-				     GTK_STOCK_OK,
-				     GTK_RESPONSE_OK);
+	dlg = gtk_message_dialog_new (NULL,
+				      (GtkDialogFlags)0,
+				      GTK_MESSAGE_INFO,
+				      GTK_BUTTONS_OK,
+				      "%s", header_text);
+	gtk_message_dialog_format_secondary_text (
+		GTK_MESSAGE_DIALOG (dlg), "%s", body_text);
+	gtk_window_set_modal (GTK_WINDOW (dlg), modal);
+
 	bonobo_control_set_transient_for (BONOBO_CONTROL (control),
 					  GTK_WINDOW (dlg),
 					  NULL);
@@ -1035,21 +1041,22 @@ overwrite_existing_file (GtkWindow *window, const gchar *file_name)
 {
 	GtkWidget *msgbox;
 	gchar *utf8_file_name;
-	gchar *msg;
 	AtkObject *obj;
 	gint ret;
 
 	utf8_file_name = g_filename_to_utf8 (file_name, -1, NULL, NULL, NULL);
-	msg = g_strdup_printf (_("A file named \"%s\" already exists."),
-			       utf8_file_name);
+	msgbox = gtk_message_dialog_new (
+		window,
+		(GtkDialogFlags)GTK_DIALOG_DESTROY_WITH_PARENT,
+		GTK_MESSAGE_QUESTION,
+		GTK_BUTTONS_NONE,
+		_("A file named \"%s\" already exists."),
+		utf8_file_name);
 	g_free (utf8_file_name);
 
-	msgbox = gpdf_hig_dialog_new (
-		GTK_STOCK_DIALOG_QUESTION, msg,
-		_("Do you want to replace it with the one you are saving?"),
-		FALSE);
-
-	g_free (msg);
+	gtk_message_dialog_format_secondary_text (
+		GTK_MESSAGE_DIALOG (msgbox),
+		_("Do you want to replace it with the one you are saving?"));
 
 	gtk_dialog_add_button (GTK_DIALOG (msgbox), 
 			       GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
@@ -1057,8 +1064,6 @@ overwrite_existing_file (GtkWindow *window, const gchar *file_name)
 	gtk_dialog_add_button (GTK_DIALOG (msgbox),
 			       _("_Replace"), GTK_RESPONSE_YES);
 
-	gtk_window_set_transient_for (GTK_WINDOW (msgbox), window);
-
 	gtk_dialog_set_default_response (GTK_DIALOG (msgbox),
 					 GTK_RESPONSE_CANCEL);
 
@@ -1076,22 +1081,20 @@ overwrite_existing_file (GtkWindow *window, const gchar *file_name)
 static void
 save_error_dialog (GtkWindow *window, const gchar *file_name)
 {
-	char *msg;
 	GtkWidget *error_dialog;
 
-	msg = g_strdup_printf (_("The file could not be saved as \"%s\"."),
-			       file_name);
+	error_dialog = gtk_message_dialog_new (
+		window,
+		(GtkDialogFlags)GTK_DIALOG_DESTROY_WITH_PARENT,
+		GTK_MESSAGE_ERROR,
+		GTK_BUTTONS_CLOSE,
+		_("The file could not be saved as \"%s\"."),
+		file_name);
 
-	error_dialog = gpdf_hig_dialog_new (GTK_STOCK_DIALOG_ERROR,
-					    msg, NULL, FALSE);
-
-	g_free (msg);
-
-	gtk_dialog_add_button (GTK_DIALOG (error_dialog),
-			       GTK_STOCK_CLOSE,
-			       GTK_RESPONSE_CLOSE);
-
-	gtk_window_set_transient_for (GTK_WINDOW (error_dialog), window);
+	/* Easy way to make the text bold while keeping the string
+	 * above free from pango markup (FIXME ?) */
+	gtk_message_dialog_format_secondary_text (
+		GTK_MESSAGE_DIALOG (error_dialog), "");
 
 	gtk_dialog_run (GTK_DIALOG (error_dialog));
 	gtk_widget_destroy (error_dialog);
@@ -1725,15 +1728,6 @@ gpdf_control_read_sidebar_state (GPdfControl *gpdf_control)
 			 NULL,
 			 gpdf_control);
 
-#ifndef USE_ANNOTS_VIEW
-	/*
-	 * If annots view is disabled and saved page id
-	 * is GPDF_ANNOTS_VIEW_PAGE_ID,  change it to Bookmarks page.
-	 */
-	if (!strncmp(page_id, GPDF_ANNOTS_VIEW_PAGE_ID, strlen(GPDF_ANNOTS_VIEW_PAGE_ID)))
-		page_id = GPDF_BOOKMARKS_VIEW_PAGE_ID;
-#endif
-	
 	/* Select sidebar page saved in gconf value sidebar_page */
 	gpdf_control_sidebar_page_changed_cb
 		(GPDF_SIDEBAR (gpdf_control->priv->gpdf_sidebar),
@@ -2334,6 +2328,8 @@ gpdf_control_sidebar_page_changed_cb (GPdfSidebar *sidebar,
 	else if (!strncmp (page_id, GPDF_ANNOTS_VIEW_PAGE_ID, strlen(GPDF_ANNOTS_VIEW_PAGE_ID)))
 		page = control->priv->gpdf_annots_view;
 #endif
+	else /* Invalid page setting: use fallback*/
+		page = control->priv->gpdf_bookmarks_view; 
 	
 	if (page)
 		gpdf_sidebar_set_content
